@@ -5,11 +5,10 @@
 # 2024 Translated from MATLAB to Python by U.A. Canbolat <utku.canbolat@fau.de>
 
 import sys
-sys.path.append('/home/vas/Desktop/Utku_Code_Review/CLUMP_Python/')
 
-from CLUMP.GenerateClump_Euclidean_3D import GenerateClump_Euclidean_3D
+from CLUMP import GenerateClump_Euclidean_3D
 import sys
-sys.path.append('../')
+sys.path.append('../../')
 
 # Load particle shape from stl file
 inputGeom = 'ParticleGeometries/Hexahedron.stl'
